package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsBaseDeviceInstall;

/**
 * 设备安装信息Mapper接口
 * 
 * @author xins
 * @date 2024-01-02
 */
public interface DmsBaseDeviceInstallMapper 
{
    /**
     * 查询设备安装信息
     * 
     * @param deviceInstallId 设备安装信息主键
     * @return 设备安装信息
     */
    public DmsBaseDeviceInstall selectDmsBaseDeviceInstallByDeviceInstallId(Long deviceInstallId);

    /**
     * 查询设备安装信息列表
     * 
     * @param dmsBaseDeviceInstall 设备安装信息
     * @return 设备安装信息集合
     */
    public List<DmsBaseDeviceInstall> selectDmsBaseDeviceInstallList(DmsBaseDeviceInstall dmsBaseDeviceInstall);

    /**
     * 新增设备安装信息
     * 
     * @param dmsBaseDeviceInstall 设备安装信息
     * @return 结果
     */
    public int insertDmsBaseDeviceInstall(DmsBaseDeviceInstall dmsBaseDeviceInstall);

    /**
     * 修改设备安装信息
     * 
     * @param dmsBaseDeviceInstall 设备安装信息
     * @return 结果
     */
    public int updateDmsBaseDeviceInstall(DmsBaseDeviceInstall dmsBaseDeviceInstall);

    /**
     * 删除设备安装信息
     * 
     * @param deviceInstallId 设备安装信息主键
     * @return 结果
     */
    public int deleteDmsBaseDeviceInstallByDeviceInstallId(Long deviceInstallId);

    /**
     * 批量删除设备安装信息
     * 
     * @param deviceInstallIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsBaseDeviceInstallByDeviceInstallIds(Long[] deviceInstallIds);
}
